summaryrefslogtreecommitdiff
path: root/src/python/gudhi/alpha_complex.pyx
diff options
context:
space:
mode:
authorROUVREAU Vincent <vincent.rouvreau@inria.fr>2019-12-05 17:57:19 +0100
committerROUVREAU Vincent <vincent.rouvreau@inria.fr>2019-12-05 17:57:19 +0100
commit6142e146e92801cafe1438bf487f3ecafa502177 (patch)
treef1c78d045aa669d478aa485221c194e6abd08bb8 /src/python/gudhi/alpha_complex.pyx
parent3757fedbf7ad387cdc06870a1db9532bbee4bab9 (diff)
nicer doc presentation
Diffstat (limited to 'src/python/gudhi/alpha_complex.pyx')
-rw-r--r--src/python/gudhi/alpha_complex.pyx4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/python/gudhi/alpha_complex.pyx b/src/python/gudhi/alpha_complex.pyx
index abac6e7b..bfb9783a 100644
--- a/src/python/gudhi/alpha_complex.pyx
+++ b/src/python/gudhi/alpha_complex.pyx
@@ -107,8 +107,8 @@ cdef class AlphaComplex:
there is very little point using anything else since it does
not save time.
:type max_alpha_square: float
- :param exact_version: Exact computation version. Default is false
- which means Safe version is used.
+ :param exact_version: :code:`EXACT` computation version if set.
+ Default is false which means :code:`SAFE` version is used.
:type exact_version: bool
:returns: A simplex tree created from the Delaunay Triangulation.
:rtype: SimplexTree